@@ -1,5 +1,9 @@
 __author__ = 'Stephan Conrad <stephan@conrad.pics>'
 
+_ARRAY_TYES = (
+    'memberOf',
+)
+
 def parseRecord(lines, accountType = "805306368"):
     if type(lines) == list:
         parse = False
@@ -28,7 +32,10 @@ def parseRecord(lines, accountType = "805306368"):
             else:
                 if tmp != {}:
                     if 'sAMAccountType' in tmp:
-                        if tmp['sAMAccountType'] == accountType:
+                        checkKey = accountType
+                        if accountType == False:
+                            checkKey = tmp['sAMAccountType']
+                        if tmp['sAMAccountType'] == checkKey:
                             user=False
                             if 'isCriticalSystemObject' in tmp:
                                 user = tmp['isCriticalSystemObject'].lower() in 'false'
